@@ -1,6 +1,6 @@
 /*
  * json_stats.c: Functions used by sadf to display statistics in JSON format.
- * (C) 1999-2022 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2023 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -36,6 +36,7 @@
 #endif
 
 extern uint64_t flags;
+extern char bat_status[][16];
 
 /*
  ***************************************************************************
@@ -46,7 +47,7 @@ extern uint64_t flags;
  * @action	Open or close action.
  ***************************************************************************
  */
-void json_markup_network(int tab, int action)
+void json_markup_network(int tab, enum json_action action)
 {
 	static int markup_state = CLOSE_JSON_MARKUP;
 
@@ -74,7 +75,7 @@ void json_markup_network(int tab, int action)
  * @action	Open or close action.
  ***************************************************************************
  */
-void json_markup_power_management(int tab, int action)
+void json_markup_power_management(int tab, enum json_action action)
 {
 	static int markup_state = CLOSE_JSON_MARKUP;
 
@@ -102,7 +103,7 @@ void json_markup_power_management(int tab, int action)
  * @action	Open or close action.
  ***************************************************************************
  */
-void json_markup_psi(int tab, int action)
+void json_markup_psi(int tab, enum json_action action)
 {
 	static int markup_state = CLOSE_JSON_MARKUP;
 
@@ -2610,3 +2611,63 @@ close_json_markup:
 		json_markup_psi(tab, CLOSE_JSON_MARKUP);
 	}
 }
+
+/*
+ * **************************************************************************
+ * Display battery statistics in JSON.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @tab		Indentation in output.
+ * @itv		Interval of time in 1/100th of a second.
+ ***************************************************************************
+ */
+__print_funct_t json_print_pwr_bat_stats(struct activity *a, int curr, int tab,
+					 unsigned long long itv)
+{
+	int i;
+	struct stats_pwr_bat *spbc, *spbp;
+	int sep = FALSE;
+
+	if (!IS_SELECTED(a->options) || (a->nr[curr] <= 0))
+		goto close_json_markup;
+
+	json_markup_power_management(tab, OPEN_JSON_MARKUP);
+	tab++;
+
+	xprintf(tab++, "\"battery\": [");
+
+	for (i = 0; i < a->nr[curr]; i++) {
+		spbc = (struct stats_pwr_bat *) ((char *) a->buf[curr] + i * a->msize);
+		spbp = (struct stats_pwr_bat *) ((char *) a->buf[!curr] + i * a->msize);
+
+		if (sep) {
+			printf(",\n");
+		}
+		sep = TRUE;
+
+		/* Battery status code should not be greater than or equal to BAT_STS_NR */
+		if (spbc->status >= BAT_STS_NR) {
+			spbc->status = 0;
+		}
+
+		xprintf0(tab, "{\"number\": %d, "
+			      "\"percent-capacity\": %u, "
+			      "\"variation\": %.2f, "
+			      "\"status\": \"%s\"}",
+		spbc->bat_id,
+		(unsigned int) spbc->capacity,
+		(double) (spbc->capacity - spbp->capacity) * 6000 / itv,
+		bat_status[(unsigned int) spbc->status]);
+	}
+
+	printf("\n");
+	xprintf0(--tab, "]");
+	tab--;
+
+	close_json_markup:
+	if (CLOSE_MARKUP(a->options)) {
+		json_markup_power_management(tab, CLOSE_JSON_MARKUP);
+	}
+}
