@@ -1,6 +1,6 @@
 /*
  * mpstat: per-processor statistics
- * (C) 2000-2022 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2000-2023 by Sebastien GODARD (sysstat <at> orange.fr)
  * Copyright (C) 2022 Oracle and/or its affiliates.
  *
  ***************************************************************************
@@ -720,7 +720,7 @@ void write_plain_cpu_stats(int dis, unsigned long long deltot_jiffies, int prev,
 				 * If the CPU is tickless then there is no change in CPU values
 				 * but the sum of values is not zero.
 				 */
-				cprintf_pc(NO_UNIT, 10, 7, 2,
+				cprintf_xpc(NO_UNIT, FALSE, 10, 7, 2,
 					   0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 100.0);
 				printf("\n");
 
@@ -728,7 +728,7 @@ void write_plain_cpu_stats(int dis, unsigned long long deltot_jiffies, int prev,
 			}
 		}
 
-		cprintf_pc(NO_UNIT, 10, 7, 2,
+		cprintf_xpc(NO_UNIT, XHIGH, 9, 7, 2,
 			   (scc->cpu_user - scc->cpu_guest) < (scp->cpu_user - scp->cpu_guest) ?
 			   0.0 :
 			   ll_sp_value(scp->cpu_user - scp->cpu_guest,
@@ -750,11 +750,12 @@ void write_plain_cpu_stats(int dis, unsigned long long deltot_jiffies, int prev,
 			   ll_sp_value(scp->cpu_guest,
 				       scc->cpu_guest, deltot_jiffies),
 			   ll_sp_value(scp->cpu_guest_nice,
-				       scc->cpu_guest_nice, deltot_jiffies),
-			   (scc->cpu_idle < scp->cpu_idle) ?
-			   0.0 :
-			   ll_sp_value(scp->cpu_idle,
-				       scc->cpu_idle, deltot_jiffies));
+				       scc->cpu_guest_nice, deltot_jiffies));
+		cprintf_xpc(NO_UNIT, XLOW, 1, 7, 2,
+			    (scc->cpu_idle < scp->cpu_idle) ?
+			    0.0 :
+			    ll_sp_value(scp->cpu_idle,
+					scc->cpu_idle, deltot_jiffies));
 		printf("\n");
 	}
 }
@@ -998,7 +999,7 @@ void write_plain_node_stats(int dis, unsigned long long deltot_jiffies,
 
 			if (!deltot_jiffies) {
 				/* All CPU in node are tickless and/or offline */
-				cprintf_pc(NO_UNIT, 10, 7, 2,
+				cprintf_xpc(NO_UNIT, FALSE, 10, 7, 2,
 					   0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 100.0);
 				printf("\n");
 
@@ -1006,7 +1007,7 @@ void write_plain_node_stats(int dis, unsigned long long deltot_jiffies,
 			}
 		}
 
-		cprintf_pc(NO_UNIT, 10, 7, 2,
+		cprintf_xpc(NO_UNIT, XHIGH, 9, 7, 2,
 			   (snc->cpu_user - snc->cpu_guest) < (snp->cpu_user - snp->cpu_guest) ?
 			   0.0 :
 			   ll_sp_value(snp->cpu_user - snp->cpu_guest,
@@ -1028,11 +1029,12 @@ void write_plain_node_stats(int dis, unsigned long long deltot_jiffies,
 			   ll_sp_value(snp->cpu_guest,
 				       snc->cpu_guest, deltot_jiffies),
 			   ll_sp_value(snp->cpu_guest_nice,
-				       snc->cpu_guest_nice, deltot_jiffies),
-			   (snc->cpu_idle < snp->cpu_idle) ?
-			   0.0 :
-			   ll_sp_value(snp->cpu_idle,
-				       snc->cpu_idle, deltot_jiffies));
+				       snc->cpu_guest_nice, deltot_jiffies));
+		cprintf_xpc(NO_UNIT, XLOW, 1, 7, 2,
+			    (snc->cpu_idle < snp->cpu_idle) ?
+			    0.0 :
+			    ll_sp_value(snp->cpu_idle,
+					snc->cpu_idle, deltot_jiffies));
 		printf("\n");
 	}
 }
@@ -1227,7 +1229,7 @@ void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int cu
 		printf("%-11s", curr_string);
 		cprintf_in(IS_STR, " %s", " all", 0);
 		/* Print total number of interrupts among all cpu */
-		cprintf_f(NO_UNIT, 1, 9, 2,
+		cprintf_f(NO_UNIT, FALSE, 1, 9, 2,
 			  S_VALUE(st_irq[prev]->irq_nr, st_irq[curr]->irq_nr, itv));
 		printf("\n");
 	}
@@ -1253,12 +1255,12 @@ void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int cu
 
 		if (!pc_itv) {
 			/* This is a tickless CPU: Value displayed is 0.00 */
-			cprintf_f(NO_UNIT, 1, 9, 2, 0.0);
+			cprintf_f(NO_UNIT, FALSE, 1, 9, 2, 0.0);
 			printf("\n");
 		}
 		else {
 			/* Display total number of interrupts for current CPU */
-			cprintf_f(NO_UNIT, 1, 9, 2,
+			cprintf_f(NO_UNIT, FALSE, 1, 9, 2,
 				  S_VALUE(sip->irq_nr, sic->irq_nr, itv));
 			printf("\n");
 		}
@@ -1504,7 +1506,7 @@ void write_plain_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 
 			if (!strcmp(p0->irq_name, q0->irq_name) || !interval) {
 				q = st_ic[prev] + (cpu - 1) * ic_nr + offset;
-				cprintf_f(NO_UNIT, 1, colwidth[j], 2,
+				cprintf_f(NO_UNIT, FALSE, 1, colwidth[j], 2,
 					  S_VALUE(q->interrupt, p->interrupt, itv));
 			}
 			else {
@@ -1512,7 +1514,7 @@ void write_plain_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 				 * Instead of printing "N/A", assume that previous value
 				 * for this new interrupt was zero.
 				 */
-				cprintf_f(NO_UNIT, 1, colwidth[j], 2,
+				cprintf_f(NO_UNIT, FALSE, 1, colwidth[j], 2,
 					  S_VALUE(0, p->interrupt, itv));
 			}
 		}
