@@ -1,6 +1,6 @@
 /*
  * sadf: System activity data formatter
- * (C) 1999-2022 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2023 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _SADF_H
@@ -9,11 +9,13 @@
 #include "sa.h"
 
 /* DTD version for XML output */
-#define XML_DTD_VERSION	"3.12"
+#define XML_DTD_VERSION	"3.13"
 
 /* Various constants */
-#define DO_SAVE		0
-#define DO_RESTORE	1
+enum {
+	DO_SAVE		= 0,
+	DO_RESTORE	= 1
+};
 
 #define IGNORE_NOTHING		0
 #define IGNORE_RESTART		1
@@ -198,12 +200,12 @@ __printf_funct_t print_pcp_header
  */
 void logic1_display_loop
 	(int, char *, struct file_activity *, struct file_magic *,
-	 struct tm *, void *);
+	 struct tstamp_ext *, void *);
 void logic2_display_loop
 	(int, char *, struct file_activity *, struct file_magic *,
-	 struct tm *, void *);
+	 struct tstamp_ext *, void *);
 void svg_display_loop
 	(int, char *, struct file_activity *, struct file_magic *,
-	 struct tm *, void *);
+	 struct tstamp_ext *, void *);
 
 #endif  /* _SADF_H */
