@@ -1,6 +1,6 @@
 /*
  * sadf_misc.c: Functions used by sadf to display special records
- * (C) 2011-2022 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2011-2023 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -777,6 +777,10 @@ __printf_funct_t print_pcp_statistics(int *tab, int action, struct activity *act
 					pcp_def_pwr_in_metrics(act[p]);
 					break;
 
+				case A_PWR_BAT:
+					pcp_def_pwr_bat_metrics(act[p]);
+					break;
+
 				case A_PWR_USB:
 					pcp_def_pwr_usb_metrics(act[p]);
 					break;
@@ -832,11 +836,20 @@ char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_dat
 	else {
 		strcpy(temp2, temp1);
 	}
-	snprintf(pre, sizeof(pre), "%s%s %s", temp2, cur_time,
-		 strlen(cur_date) ? (PRINT_LOCAL_TIME(flags) ? my_tz
-							     : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
-										       : "UTC"))
-				  : "");
+
+	if (strlen(cur_date) && (!PRINT_TRUE_TIME(flags) ||
+				 (PRINT_TRUE_TIME(flags) && strlen(file_hdr->sa_tzname)))) {
+		snprintf(pre, sizeof(pre), "%s%s %s", temp2, cur_time,
+			 PRINT_LOCAL_TIME(flags) ? my_tz
+						 : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									   : "UTC"));
+	}
+	else {
+		snprintf(pre, sizeof(pre), "%s%s", temp2, cur_time);
+	}
+
+
+	
 	pre[sizeof(pre) - 1] = '\0';
 
 	if (DISPLAY_HORIZONTALLY(flags)) {
@@ -859,14 +872,14 @@ char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_dat
  * @itv		Interval of time with preceding record.
  * @record_hdr	Record header for current sample (unused here).
  * @file_hdr	System activity file standard header.
- * @flags	Flags for common options.
+ * @flags	Flags for common options (unused here).
  *
  * RETURNS:
  * Pointer on the "timestamp" string.
  ***************************************************************************
  */
 __tm_funct_t print_ppc_timestamp(void *parm, int action, char *cur_date,
-				 char *cur_time, char * my_tz, unsigned long long itv,
+				 char *cur_time, char *my_tz, unsigned long long itv,
 				 struct record_header *record_hdr,
 				 struct file_header *file_hdr, unsigned int flags)
 {
@@ -1023,12 +1036,18 @@ __tm_funct_t print_raw_timestamp(void *parm, int action, char *cur_date,
 	static char pre[80];
 
 	if (action & F_BEGIN) {
-		snprintf(pre, sizeof(pre), "%s %s", cur_time,
-			 strlen(cur_date) ? (PRINT_LOCAL_TIME(flags) ? my_tz
-								     : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
-											       : "UTC"))
-					  : "");
+		if (strlen(cur_date) && (!PRINT_TRUE_TIME(flags) ||
+					 (PRINT_TRUE_TIME(flags) && strlen(file_hdr->sa_tzname)))) {
+			snprintf(pre, sizeof(pre), "%s %s", cur_time,
+				 PRINT_LOCAL_TIME(flags) ? my_tz
+							 : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+										   : "UTC"));
+			}
+			else {
+				snprintf(pre, sizeof(pre), "%s", cur_time);
+			}
 		pre[sizeof(pre) - 1] = '\0';
+
 		return pre;
 	}
 
@@ -1676,6 +1695,39 @@ __nr_t count_new_int(struct activity *a, int curr)
 	return nr;
 }
 
+/*
+ * **************************************************************************
+ * Count the number of new batteries in current sample. If a new
+ * battery is found then add it to the linked list starting at
+ * @a->item_list.
+ * Mainly useful to create a list of battery names (BATx) that will be used
+ * as instance names for sadf PCP output format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ *
+ * RETURNS:
+ * Number of new batteries identified in current sample that were not
+ * previously in the list.
+ ***************************************************************************
+ */
+__nr_t count_new_bat(struct activity *a, int curr)
+{
+	int i, nr = 0;
+	struct stats_pwr_bat *spbc;
+	char bat_name[16];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+		spbc = (struct stats_pwr_bat *) ((char *) a->buf[curr] + i * a->msize);
+
+		snprintf(bat_name, sizeof(bat_name), "BAT%d", (int) spbc->bat_id);
+		nr += add_list_item(&(a->item_list), bat_name, sizeof(bat_name));
+	}
+
+	return nr;
+}
+
 /*
  ***************************************************************************
  * Init custom color palette used to draw graphs (sadf -g).
